@@ -10,7 +10,7 @@ from models import EmailAddress
 from utils import send_activation, get_template
 from django.utils.translation import ugettext_lazy as _
 from django.core.urlresolvers import reverse
-
+from signals import user_added_email, user_sent_activation, user_activated_email
 
 @login_required
 def email_add(request):
@@ -21,17 +21,18 @@ def email_add(request):
     if request.method == 'POST':
         form = EmailAddressForm(user=request.user, data=request.POST)
         if form.is_valid():
-            form.save()
+            email = form.save()
+            user_added_email.send(sender=EmailAddress, email_address=email)
             Msg.add_message (request, Msg.SUCCESS, _('email address added'))
             form = EmailAddressForm(user=request.user)
     else:
         form = EmailAddressForm(user=request.user)
 
-    emails_list = EmailAddress.objects.filter(user=request.user).order_by('-is_primary')
+    emails_list = EmailAddress.objects.filter(user=request.user).order_by('-is_primary').order_by('-is_active')
     return render_to_response(get_template('emailmgr_email_list.html'),
                               {
-                                'emails_list': emails_list,
-                                'add_email_form': form
+                                'email_list': emails_list,
+                                'email_form': form
                               },
                               context_instance=RequestContext(request)
                               )
@@ -78,6 +79,9 @@ def email_send_activation(request, identifier="somekey"):
         Msg.add_message (request, Msg.SUCCESS, _('email address already activated'))
     else:
         send_activation(request, identifier)
+        email.is_activation_sent = True
+        email.save()
+        user_sent_activation.send(sender=EmailAddress, email_address=email)
         Msg.add_message (request, Msg.SUCCESS, _('activation email sent'))
 
     return HttpResponseRedirect(reverse('emailmgr_email_list'))
@@ -100,6 +104,7 @@ def email_activate(request, identifier="somekey"):
         else:
             email.is_active = True
             email.save()
+            user_activated_email.send(sender=EmailAddress, email_address=email)
             Msg.add_message (request, Msg.SUCCESS, _('email address is now active'))
 
     return HttpResponseRedirect(reverse('emailmgr_email_list'))
@@ -128,11 +133,11 @@ def email_list(request):
     An ``add`` email form will be passed in the template so user can add new email inline
     """
     form = EmailAddressForm(user=request.user)
-    emails_list = EmailAddress.objects.filter(user=request.user).order_by('-is_primary')
+    emails_list = EmailAddress.objects.filter(user=request.user).order_by('-is_primary').order_by('-is_active')
     return render_to_response(get_template('emailmgr_email_list.html'),
                               {
-                                'emails_list': emails_list,
-                                'add_email_form': form
+                                'email_list': emails_list,
+                                'email_form': form
                               },
                               context_instance=RequestContext(request)
                               )
